function e = enutik( norm_r, rEx, norm_Ex, lam, nu)
%ENUTIK	error estimate for Tikhonov regularization (square case)
%
%   e = enutik(norm_r,rEx,norm_Ex,lam,nu) computes the error estimate for a set
%   of regularized solutions (x(:,i),i=1,...,k) of a square nonsingular linear
%   system, computed by minimizing the Tikhonov functional
%	|| A*x - b ||^2 + lambda^2 * || H*x ||^2
%
%   The input parameters norm_r, rEx, norm_Ex and lam are k-vectors such that
%	norm_r(i) = norm(r(:,i)), where r(:,i)=b-A*x(:,i)
%	rEx(i) = r(:,i)'*H'*H*x(:,i)
%	norm_Ex(i) = norm(H'*H*x(:,i))
%	lam(i) is the regularization parameter corresponding to x(:,i)
%   nu is the index of the estimate (real number, default 3).
%
%   See also enu, ehatnu, etanu, etanutik.

% This function computes the estimate etilde_nu defined in eq. (25) of the
% paper 
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for linear systems with applications to regularization.
%   Numer. Algorithms, 49(1-4):85-104, 2008.
% or in eq. (3.12) of the paper
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for the regularization of least squares problems.
%   Numer. Algorithms, 2009. In press. 

%	Giuseppe Rodriguez,  31-01-08
% 	Email: rodriguez@unica.it

if nargin < 5,  nu = 3;  end
e = (norm_r.^(nu-1)) .* (abs(rEx).^(3-nu)) .* (norm_Ex.^(nu-4)) ./ (lam.^2);

